# Elisa - Home multimedia server
# Copyright (C) 2006 Fluendo, S.A. (www.fluendo.com).
# All rights reserved.
# 
# This software is available under three license agreements.
# 
# There are various plugins and extra modules for Elisa licensed
# under the MIT license. For instance our upnp module uses this license.
# 
# The core of Elisa is licensed under GPL version 2.
# See "LICENSE.GPL" in the root of this distribution including a special 
# exception to use Elisa with Fluendo's plugins.
# 
# The GPL part is also available under a commerical licensing
# agreement.
# 
# The second license is the Elisa Commercial License Agreement.
# This license agreement is available to licensees holding valid
# Elisa Commercial Agreement licenses.
# See "LICENSE.Elisa" in the root of this distribution.

import sys
import os
from elisa.core import __version__

import setuptools
from setuptools import setup, find_packages
from setuptools.command import test
from setuptools.command import install
from setuptools.command import build_py
from pkg_resources import *
from twisted.scripts import trial
from elisa.extern import msgfmt

if sys.platform == "win32":
    import py2exe

def override_check_test_suite(dist, attr, value):
    if not isinstance(value, list):
        raise DistutilsSetupError("test_suite must be a list")
    
setuptools.dist.check_test_suite = override_check_test_suite

class TrialTest(test.test):
    """
    Twisted Trial setuptools command
    """

    def finalize_options(self):
        if self.test_suite is None:
            if self.test_module is None:
                self.test_suite = self.distribution.test_suite
            else:
                self.test_suite = self.test_module+".test_suite"
        elif self.test_module:
            raise DistutilsOptionError(
                "You may specify a module or a suite, but not both"
            )

        self.test_args = self.test_suite

        if self.verbose:
            self.test_args.insert(0,'--verbose')
    
    def run_tests(self):
        config = trial.Options()
        config.parseOptions()

        verbose = '--verbose'
        if verbose in self.test_args:
            self.test_args.remove(verbose)
        config['tests'] = self.test_args
        
        trial._initialDebugSetup(config)
        trialRunner = trial._makeRunner(config)
        suite = trial._getSuite(config)
        if config['until-failure']:
            test_result = trialRunner.runUntilFailure(suite)
        else:
            test_result = trialRunner.run(suite)

# create .mo files from .po locales if needed
class ElisaBuildPy(build_py.build_py):
    
    def run(self):        
        i18n_dir = os.path.join(os.path.dirname(__file__), 'elisa',
                                'core', 'i18n')
        for path, names, filenames in os.walk(i18n_dir):
            for i, dirname in enumerate(names):
                if dirname.startswith('.'):
                    del names[i]
                for f in filenames:
                    if f.endswith('.po'):
                        src = os.path.join(path, f)
                        dest = src[:len(src) - 3] + '.mo'
                        # compile the .po if necessary
                        if not os.path.exists(dest):
                            print 'Compiling %s' % src
                            msgfmt.make(src, dest)
                        else:
                            src_mtime = os.stat(src)[8]
                            dest_mtime = os.stat(dest)[8]
                            if src_mtime > dest_mtime:
                                print 'Compiling %s' % src
                                msgfmt.make(src, dest)
        build_py.build_py.run(self)

data_files = []
if sys.platform == "win32":
    data_files=[("elisa.egg-info",["elisa.egg-info\\entry_points.txt",
                                   "elisa.egg-info\\dependency_links.txt",
                                   "elisa.egg-info\\not-zip-safe",
                                   "elisa.egg-info\\PKG-INFO",
                                   "elisa.egg-info\\SOURCES.txt",
                                   "elisa.egg-info\\top_level.txt"]),
                ("elisa\\core\\plugins", ["elisa\\core\\plugins\\pictures.py"])]
    
elif sys.platform == 'linux2':
    # only root user can write in /usr/share on linux platform
    if os.getuid() == 0:
        data_files=[('/usr/share/pixmaps', ['elisa.png']),
                    ('/usr/share/applications', ['elisa.desktop'])]

icon_path = os.path.join('win32', 'elisa.ico')

setup(cmdclass={'test': TrialTest, 'build_py': ElisaBuildPy},
      console= [
        {
          'script': 'elisa.py',
          'icon_resources': [(1, icon_path)],          
        }
      ],
      data_files=data_files,
      name="elisa",
      version=__version__,
      description="""Fluendo Media Center""",
      author="The Elisa Team",
      author_email="lionel@fluendo.com",
      maintainer="Philippe Normand",
      maintainer_email="philippe@fluendo.com",
      long_description="""\
Elisa is an open media center system to watch, listen, manage and
share videos, files and music. It uses GStreamer, Python and OpenGL
technologies. """,
      url="http://www.fluendo.com/elisa/",
      keywords=['multimedia', 'gstreamer', 'opengl'],
      classifiers = ['Development Status :: 3 - Alpha',
                     'Environment :: X11 Applications',
                     'Intended Audience :: End Users/Desktop',
                     'Natural Language :: English',
                     'Operating System :: OS Independent',
                     'Programming Language :: Python',
                     'Topic :: Multimedia :: Graphics :: 3D Rendering',
                     'Topic :: Multimedia :: Sound/Audio',
                     'Topic :: Multimedia :: Video',
                     ],
      test_suite = ['elisa.core.tests', 'elisa.core.plugins.tests'],
      zip_safe = False,
      packages=find_packages(),
      package_data={
      'elisa.core.plugins.skins.default': ['pictures/*.png',
                                           'pictures/unscaled/*.png',
                                           'pictures/config/*.png',
                                           'pictures/128X128/*.png',
                                           'pictures/256X256/*.png',
                                           'pictures/512X512/*.png'],
      'elisa.core.plugins': ['data/*.png', 'data/*.lirc',
                             'data/weather/*.png',
                             'data/weather/*.csv', 'data/stations_big.xml'],
      'elisa.core': ['i18n/*/LC_MESSAGES/*.mo']},
      
      entry_points="""
      [elisa.plugins.queue]
      default_queue = elisa.core.player.default_queue:DefaultQueue
      smart_queue = elisa.core.player.smart_queue:SmartQueue
      
      [elisa.plugins.data]
      local_fs = elisa.core.plugins.local_fs:LocalFSPlugin
      vfs = elisa.core.plugins.vfs:VFSPlugin
      upnp = elisa.core.plugins.upnp:UPnPPlugin
      meta_fs = elisa.core.plugins.meta_fs:MetaFSPlugin
      ipod = elisa.core.plugins.ipod:IPodPlugin
      daap_fs = elisa.core.plugins.daap_fs:DaapFSPlugin
      flickr = elisa.core.plugins.flickr:FlickrPlugin
      
      [elisa.skins]
      default_skin = elisa.core.plugins.skins.default.skin:ElisaSkin
      
      [elisa.plugins.misc]
      lirc = elisa.core.plugins.lirc:LIRCPlugin
      web_radio = elisa.core.plugins.web_radio:WebRadioTreePlugin
      hal = elisa.core.plugins.hal:HalPlugin
      http_server = elisa.core.plugins.http_server:HttpServerPlugin
      upnp_server = elisa.core.plugins.upnp_server:UPnPServerPlugin
      upnp_renderer = elisa.core.plugins.upnp_renderer:UPnPRendererPlugin      
      audioscrobbler = elisa.core.plugins.audioscrobbler:AudioScrobblerPlugin
      lastfm = elisa.core.plugins.lastfm:LastFMPlayer
      
      [elisa.plugins.services]
      config = elisa.core.plugins.config:ConfigTreePlugin
      weather = elisa.core.plugins.weather:WeatherPlugin
      
      [elisa.plugins]
      pictures = elisa.core.plugins.pictures:PicturesTreePlugin
      movies = elisa.core.plugins.movies:MoviesTreePlugin
      music = elisa.core.plugins.music:MusicTreePlugin
      dvd = elisa.core.plugins.dvd:DVDTreePlugin
      services = elisa.core.plugins.services:ServicesTreePlugin
      
      [gui_scripts]
      elisa = elisa.core.application:start
      
      [console_scripts]
      elisa-client = elisa.core.client:main
      """,
##       extras_require = {'SQLite': ['pysqlite'],
##                        }
    )
